@@ -80,6 +80,13 @@ namespace adaptive
         static_cast<uint32_t>(kodi::addon::GetSettingInt("MAXBUFFERDURATION"));
   }
 
+  void AdaptiveTree::Uninitialize()
+  {
+    // Stop the update thread before the tree class deconstruction otherwise derived classes
+    // will be destructed early, so while an update could be just started
+    m_updThread.Stop();
+  }
+
   void AdaptiveTree::PostOpen(const UTILS::PROPERTIES::KodiProperties& kodiProps)
   {
     // A manifest can provide live delay value, if not so we use our default
@@ -409,9 +416,8 @@ namespace adaptive
       manifestHeaders[headerIt.first] = headerIt.second;
     }
 
-    // Append manifest parameters, only if not already provided (e.g. manifest update)
-    if (url.find('?') == std::string::npos)
-      URL::AppendParameters(url, m_manifestParams);
+    // Append manifest parameters
+    URL::AppendParameters(url, m_manifestParams);
 
     return download(url, manifestHeaders, data, respHeaders);
   }
@@ -541,13 +547,12 @@ namespace adaptive
   AdaptiveTree::TreeUpdateThread::~TreeUpdateThread()
   {
     // assert(m_waitQueue == 0); // Debug only, missing resume
+
+    // We assume that Stop() method has been called before the deconstruction
     m_threadStop = true;
 
     if (m_thread.joinable())
-    {
-      m_cvUpdInterval.notify_all(); // Unlock possible waiting
       m_thread.join();
-    }
   }
 
   void AdaptiveTree::TreeUpdateThread::Initialize(AdaptiveTree* tree)
@@ -572,6 +577,8 @@ namespace adaptive
         // If paused, wait until last "Resume" will be called
         std::unique_lock<std::mutex> lckWait(m_waitMutex);
         m_cvWait.wait(lckWait, [&] { return m_waitQueue == 0; });
+        if (m_threadStop)
+          break;
 
         updLck.lock();
         m_tree->RefreshLiveSegments();
@@ -595,4 +602,13 @@ namespace adaptive
       m_cvWait.notify_all();
   }
 
+  void AdaptiveTree::TreeUpdateThread::Stop()
+  {
+    m_threadStop = true;
+    // If an update is already in progress wait until exit
+    std::lock_guard<std::mutex> updLck{m_updMutex};
+    m_cvUpdInterval.notify_all();
+    m_cvWait.notify_all();
+  }
+
   } // namespace adaptive
