@@ -20,6 +20,7 @@
 #include <map>
 #include <memory>
 #include <mutex>
+#include <optional>
 #include <sstream>
 #include <string>
 #include <thread>
@@ -40,6 +41,7 @@ class IRepresentationChooser;
 namespace adaptive
 {
 
+constexpr uint64_t NO_PTS_VALUE = std::numeric_limits<uint64_t>::max();
 
 template<typename T>
 struct ATTR_DLL_LOCAL SPINCACHE
@@ -195,6 +197,7 @@ public:
     // Same content of "media" property but with placeholder $RepresentationID$ and $Bandwidth$ filled
     std::string media_url;
     unsigned int timescale, duration;
+    std::optional<uint64_t> m_segEndNumber;
   };
 
   struct Representation
@@ -248,6 +251,7 @@ public:
     ContainerType containerType_;
     SegmentTemplate segtpl_;
     uint64_t startNumber_;
+    std::optional<uint64_t> m_segEndNumber;
     uint64_t nextPts_;
     //SegmentList
     uint64_t ptsOffset_;
@@ -343,6 +347,7 @@ public:
     std::vector<Representation*> representations_;
     SPINCACHE<uint32_t> segment_durations_;
     SegmentTemplate segtpl_;
+    std::optional<uint64_t> m_segEndNumber;
 
     const uint32_t get_segment_duration(size_t pos)
     {
@@ -535,6 +540,11 @@ public:
    */
   virtual void Configure(const UTILS::PROPERTIES::KodiProperties& kodiProps);
 
+  /*!
+   * \brief Performs operations to stop running process and release resources.
+   */
+  virtual void Uninitialize();
+
   virtual bool open(const std::string& url) = 0;
   virtual bool open(const std::string& url, std::map<std::string, std::string> additionalHeaders) = 0;
 
@@ -639,6 +649,9 @@ public:
     // \brief As "std::mutex" unlock, but resume the manifest updates (support std::lock_guard).
     void unlock() { Resume(); }
 
+    // \brief Stop performing new updates.
+    void Stop();
+
   private:
     void Worker();
     void Pause();
