@@ -63,6 +63,9 @@ private:
   uint32_t m_IncludedStreams[16];
   bool m_checkChapterSeek = false;
   int m_failedSeekTime = ~0;
+  // The last PTS of the segment package fed to kodi.
+  // NO_PTS_VALUE only when playback starts or a new period starts
+  std::atomic<uint64_t> m_lastPts{adaptive::NO_PTS_VALUE};
 
   void UnlinkIncludedStreams(SESSION::CStream* stream);
 };
