@@ -44,8 +44,7 @@ public:
   virtual bool TimeSeek(uint64_t pts, bool preceeding) = 0;
   virtual void SetPTSOffset(uint64_t offset) = 0;
   virtual int64_t GetPTSDiff() const = 0;
-  virtual void SetStartPTS(uint64_t pts) = 0;
-  virtual uint64_t GetStartPTS() const = 0;
+  virtual void SetPTSDiff(uint64_t pts) {}
   virtual bool GetNextFragmentInfo(uint64_t& ts, uint64_t& dur) = 0;
   virtual uint32_t GetTimeScale() const = 0;
   virtual AP4_UI32 GetStreamId() const = 0;
