@@ -11,6 +11,7 @@
 #include "../Session.h"
 #include "../utils/FFmpeg.h"
 #include "../utils/MemUtils.h"
+#include "../utils/UrlUtils.h"
 #include "../utils/log.h"
 
 #include <kodi/Filesystem.h>
@@ -27,16 +28,27 @@ struct SubtitlePacketExtraData
 };
 } // unnamed namespace
 
-CSubtitleSampleReader::CSubtitleSampleReader(const std::string& url,
-                                           AP4_UI32 streamId,
-                                           const std::string& codecInternalName)
+CSubtitleSampleReader::CSubtitleSampleReader(
+    std::string url,
+    AP4_UI32 streamId,
+    const std::string& codecInternalName,
+    std::string_view streamParams,
+    const std::map<std::string, std::string>& streamHeaders)
   : m_streamId{streamId}
 {
+  // Append stream parameters
+  URL::AppendParameters(url, streamParams);
+
   // open the file
   kodi::vfs::CFile file;
   if (!file.CURLCreate(url))
     return;
 
+  for (auto& header : streamHeaders)
+  {
+    file.CURLAddOption(ADDON_CURL_OPTION_HEADER, header.first, header.second);
+  }
+
   file.CURLAddOption(ADDON_CURL_OPTION_PROTOCOL, "seekable", "0");
   file.CURLAddOption(ADDON_CURL_OPTION_PROTOCOL, "acceptencoding", "gzip");
   file.CURLOpen(ADDON_READ_CHUNKED | ADDON_READ_NO_CACHE);
@@ -84,8 +96,6 @@ AP4_Result CSubtitleSampleReader::Start(bool& bStarted)
     return AP4_SUCCESS;
 
   m_started = true;
-  m_pts = GetStartPTS();
-  m_ptsDiff = GetStartPTS();
   return AP4_SUCCESS;
 }
 
@@ -94,7 +104,7 @@ AP4_Result CSubtitleSampleReader::ReadSample()
   if (m_codecHandler->ReadNextSample(m_sample,
                                      m_sampleData)) // Read the sample data from a file url
   {
-    m_pts = (m_sample.GetCts() * 1000) + GetStartPTS();
+    m_pts = (m_sample.GetCts() * 1000);
     return AP4_SUCCESS;
   }
   else if (m_adByteStream) // Read the sample data from a segment file stream (e.g. HLS)
@@ -131,12 +141,11 @@ AP4_Result CSubtitleSampleReader::ReadSample()
           auto currentSegment = rep->current_segment_;
           if (currentSegment)
           {
-            m_codecHandler->Transform(currentSegment->startPTS_ + GetStartPTS(),
+            m_codecHandler->Transform(currentSegment->startPTS_,
                                       currentSegment->m_duration, segData, 1000);
             if (m_codecHandler->ReadNextSample(m_sample, m_sampleData))
             {
               m_pts = m_sample.GetCts();
-              m_ptsDiff = m_pts - m_ptsOffset;
               return AP4_SUCCESS;
             }
           }
@@ -194,6 +203,14 @@ bool CSubtitleSampleReader::TimeSeek(uint64_t pts, bool preceeding)
   }
 }
 
+void CSubtitleSampleReader::SetPTSDiff(uint64_t pts)
+{
+  // Its needed set the PTS diff from the timing stream
+  // to allow sync segmented subtitles for cases like
+  // HLS with multiple periods
+  m_ptsDiff = pts;
+}
+
 void CSubtitleSampleReader::SetDemuxPacketSideData(DEMUX_PACKET* pkt,
                                                    std::shared_ptr<SESSION::CSession> session)
 {
