@@ -35,8 +35,6 @@ public:
   }
   bool TimeSeek(uint64_t pts, bool preceeding) override;
   void SetPTSOffset(uint64_t offset) override { m_ptsOffs = offset; }
-  uint64_t GetStartPTS() const override { return m_startPts; }
-  void SetStartPTS(uint64_t pts) override { m_startPts = pts; }
   int64_t GetPTSDiff() const override { return m_ptsDiff; }
   bool GetNextFragmentInfo(uint64_t& ts, uint64_t& dur) override { return false; }
   uint32_t GetTimeScale() const override { return 90000; }
@@ -53,7 +51,6 @@ private:
   uint64_t m_dts{0};
   uint64_t m_ptsOffs{~0ULL};
   int64_t m_ptsDiff{0};
-  uint64_t m_startPts{STREAM_NOPTS_VALUE};
   bool m_eos{false};
   bool m_started{false};
   CAdaptiveByteStream* m_adByteStream;
