@@ -31,7 +31,7 @@ bool isUrl(std::string url,
   if (url.empty())
     return false;
 
-  if (validateLenght && url.size() >= 2083)
+  if (validateLenght && url.size() > 8000) // Minimum length recommended by RFC 9110, section 4.1
     return false;
 
   if (!allowFragments && url.find('#') != std::string::npos)
@@ -179,20 +179,35 @@ std::string UTILS::URL::RemoveParameters(std::string url, bool removeFilenamePar
   return url;
 }
 
-void UTILS::URL::AppendParameters(std::string& url, std::string params)
+void UTILS::URL::AppendParameters(std::string& url, std::string_view params)
 {
   if (params.empty())
     return;
 
-  if (url.find_first_of('?') == std::string::npos)
-    url += "?";
-  else
-    url += "&";
+  params.remove_prefix(params.front() == '&' || params.front() == '?' ? 1 : 0);
+  size_t keyValDividerPos;
+  while ((keyValDividerPos = params.find('=')) != std::string::npos)
+  {
+    size_t ampersandPos = params.find('&');
+    std::string paramKey{params.substr(0, keyValDividerPos)};
 
-  if (params.front() == '&' || params.front() == '?')
-    params.erase(params.begin());
+    // if param key is not in url add it
+    if (url.find('?' + paramKey + '=') == std::string::npos &&
+        url.find('&' + paramKey + '=') == std::string::npos)
+    {
+      url += url.find_first_of('?') == std::string::npos ? '?' : '&';
+      url += paramKey + '=';
+      if (ampersandPos != std::string::npos)
+        url += params.substr(keyValDividerPos + 1, ampersandPos - keyValDividerPos - 1);
+      else
+        url += params.substr(keyValDividerPos + 1);
+    }
 
-  url += params;
+    if (ampersandPos != std::string::npos)
+      params = params.substr(ampersandPos + 1);
+    else
+      break;
+  }
 }
 
 std::string UTILS::URL::GetDomainUrl(std::string url)
